#!/bin/bash
#Created by: Matt "openMosixview" Rechemburg
#Cleanup by: Gian Paolo "rejected" Ghilardi

RPMCOMMAND="rpmbuild"


####  COLOR FUNCTIONS ####

function setRed()
{
	echo -en "\033[31m"
}

function setGreen()
{
	echo -en "\033[32m"
}

function setBlue()
{
	echo -en "\033[36m"
}

function setGray()
{
	echo -en "\033[37m"
}

function setNormal()
{
	echo -en "\033[0m"
}
#### END OF COLOR FUNCTIONS ####


function testExitCode()
{
	if [ "$?" -ne 0 ]
	then
		setGreen
		echo "  <ERROR> make failed!"
		echo "  <ERROR> FORCED EXIT"
		setNormal
		exit
	fi
}





#### GLOBAL VARS ####

GOMD_VERSION=0.1
RH_RPM_SOURCE_DIR=/usr/src/redhat
MDK_RPM_SOURCE_DIR=/usr/src/RPM
SUSE_RPM_SOURCE_DIR=/usr/src/packages
CURRENT_DIR=`pwd`

#### END OF GLOBAL VARS ####

clear
setRed
echo " "
echo "-------------------------"
echo "| GOMD RPM BUILD SCRIPT |"
echo "------------------------- "



echo " "
setRed
echo "1)INITIALIZING..."
setGray
echo "This program will create:"
echo "- a compressed file with the gomd sources"
echo "- a ready-to-install RPM packet"



echo " "
setRed
echo "2)DETERMINING CURRENT DISTRO..."
setGray
REL_FILE=$(ls /etc/*-release)
DISTRO1=$(echo $REL_FILE | grep mandrake | wc -l)
DISTRO2=$(echo $REL_FILE | grep SuSE | wc -l)
DISTRO3=$(echo $REL_FILE | grep redhat | wc -l)
if   [ "$DISTRO1" -eq 1 ]; then
	echo "Distro: Mandrake."
	RPM_SOURCES_DIR=$MDK_RPM_SOURCE_DIR
elif [ "$DISTRO2" -eq 1 ]; then
	echo "Distro: SuSE."
	RPM_SOURCES_DIR=$SUSE_RPM_SOURCE_DIR
	RPMCOMMAND="rpm"
elif [ "$DISTRO3" -eq 1 ]; then
	echo "Distro: RedHat."
	RPM_SOURCES_DIR=$RH_RPM_SOURCE_DIR
else [ -z "$RPM_SOURCES_DIR" ]
	echo "Distro: unknown."
	setGreen
	echo "  <ERROR> cannot continue!"
	echo "  <ERROR> FORCED EXIT"
	setNormal
	exit
fi



echo " "
setRed
echo "3)BUILD SOURCES"
setGray
echo "- Cleaning up code"
for i in `find ../.. -name "Makefile*"`
do
	echo -n "  => clean code in $i..."
	make -f $i clean &> /dev/null
	testExitCode
	echo "done."
done
echo "- Cleaning up previous stuff..."
echo -n "  => clean gomd-$GOMD_VERSION..."
/bin/rm -rf /tmp/gomd-$GOMD_VERSION
echo "done."
echo -n "  => clean gomd stuff in $RPM_SOURCES_DIR and subdirs..."
/bin/rm -f $RPM_SOURCES_DIR/SOURCES/gomd-$GOMD_VERSION.tar*
/bin/rm -f $RPM_SOURCES_DIR/RPMS/i386/gomd-$GOMD_VERSION*.rpm
/bin/rm -f $RPM_SOURCES_DIR/SRPMS/gomd-$GOMD_VERSION*.rpm
echo "done."
echo "- Creating /tmp/gomd-$GOMD_VERSION directory."
mkdir -p /tmp/gomd-$GOMD_VERSION
echo "- Copying  sources to /tmp/gomd-$GOMD_VERSION directory."
/bin/cp -ar ../* /tmp/gomd-$GOMD_VERSION
echo "- Entering /tmp directory."
cd /tmp
echo "- Packing the sources"
tar -cvf $RPM_SOURCES_DIR/SOURCES/gomd-$GOMD_VERSION.tar gomd-$GOMD_VERSION &> /dev/null
gzip $RPM_SOURCES_DIR/SOURCES/gomd-$GOMD_VERSION.tar &> /dev/null
echo -n "  => compressed file: "
echo `ls $RPM_SOURCES_DIR/SOURCES/gomd-$GOMD_VERSION.tar.*`



echo " "
setRed
echo "3)CREATE THE GOMD RPM FILE"
setGray
echo "- Entering /tmp/gomd-$GOMD_VERSION/packaging directory."
cd /tmp/gomd-$GOMD_VERSION/packaging
echo "- Creating the RPM file..."
echo "  => using gomd.spec file."
setBlue
$RPMCOMMAND -ba gomd.spec
testExitCode



echo " "
cd ..
setRed
echo "4)BEFORE EXITING..."
setGray
echo "- Returning to $CURRENT_DIR directory."
cd $CURRENT_DIR
setNormal



echo " "
cd ..
setRed
echo "5)EXITING"
setNormal
